You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pinot.apache.org by ne...@apache.org on 2019/01/24 19:43:43 UTC

[incubator-pinot] branch segment_status_checker_integration_test updated: Increase initial delay for SegmentStatusChecker to run

This is an automated email from the ASF dual-hosted git repository.

nehapawar pushed a commit to branch segment_status_checker_integration_test
in repository https://gitbox.apache.org/repos/asf/incubator-pinot.git


The following commit(s) were added to refs/heads/segment_status_checker_integration_test by this push:
     new b454ce9  Increase initial delay for SegmentStatusChecker to run
b454ce9 is described below

commit b454ce9061259f398cf18e424cc29bc84a8b17d5
Author: Neha Pawar <np...@linkedin.com>
AuthorDate: Thu Jan 24 11:43:28 2019 -0800

    Increase initial delay for SegmentStatusChecker to run
---
 .../periodic/tasks/SegmentStatusCheckerIntegrationTest.java         | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/pinot-integration-tests/src/test/java/org/apache/pinot/integration/tests/controller/periodic/tasks/SegmentStatusCheckerIntegrationTest.java b/pinot-integration-tests/src/test/java/org/apache/pinot/integration/tests/controller/periodic/tasks/SegmentStatusCheckerIntegrationTest.java
index 23be2c2..deefc4a 100644
--- a/pinot-integration-tests/src/test/java/org/apache/pinot/integration/tests/controller/periodic/tasks/SegmentStatusCheckerIntegrationTest.java
+++ b/pinot-integration-tests/src/test/java/org/apache/pinot/integration/tests/controller/periodic/tasks/SegmentStatusCheckerIntegrationTest.java
@@ -58,7 +58,7 @@ public class SegmentStatusCheckerIntegrationTest extends BaseClusterIntegrationT
   private String errorOfflineTable = "table4_OFFLINE";
   private String realtimeTableErrorState = "table5_REALTIME";
 
-  private static final int SEGMENT_STATUS_CHECKER_INITIAL_DELAY_SECONDS = 40;
+  private static final int SEGMENT_STATUS_CHECKER_INITIAL_DELAY_SECONDS = 60;
 
   @BeforeClass
   public void setUp() throws Exception {
@@ -66,7 +66,7 @@ public class SegmentStatusCheckerIntegrationTest extends BaseClusterIntegrationT
 
     startZk();
 
     // Set initial delay of 40 seconds for the segment status checker, to allow time for tables setup.
     // By default, it will pick a random delay between 120s and 300s
     ControllerConf controllerConf = getDefaultControllerConfiguration();
     controllerConf.setStatusCheckerInitialDelayInSeconds(SEGMENT_STATUS_CHECKER_INITIAL_DELAY_SECONDS);
@@ -109,7 +109,7 @@ public class SegmentStatusCheckerIntegrationTest extends BaseClusterIntegrationT
     setupRealtimeTable(realtimeTableErrorState);
 
     // we need to wait for SegmentStatusChecker to finish at least 1 run
-    Thread.sleep(TimeUnit.MILLISECONDS.convert(SEGMENT_STATUS_CHECKER_INITIAL_DELAY_SECONDS, TimeUnit.SECONDS));
+    Thread.sleep(TimeUnit.MILLISECONDS.convert(SEGMENT_STATUS_CHECKER_INITIAL_DELAY_SECONDS + 10, TimeUnit.SECONDS));
   }
 
   private void setupOfflineTable(String table) throws Exception {


---------------------------------------------------------------------
@@ -66,7 +66,7 @@ public class SegmentStatusCheckerIntegrationTest extends BaseClusterIntegrationT
     startZk();
 
-    // Set initial delay of 40 seconds for the segment status checker, to allow time for tables setup.
+    // Set initial delay of 60 seconds for the segment status checker, to allow time for tables setup.
     // By default, it will pick a random delay between 120s and 300s
     ControllerConf controllerConf = getDefaultControllerConfiguration();
To unsubscribe, e-mail: commits-unsubscribe@pinot.apache.org
For additional commands, e-mail: commits-help@pinot.apache.org